<?php
/*
 * VtSoftware
 * PHP Vendégkönyv
 *
 * guestbook.class.php
 * Vendégkönyv Osztály
 *
 * http://vtsoftware.hu
 * info@vtsoftware.hu
 * 2012. Feb. 13.
 */
  class GuestBook {
    /**
     * Adatbázisfájl
     * @private
     * @type string
     */
    private $dbfile = "./db.json";
    /**
     * Elemek tárolása
     * @private
     * @type array
     */
    private $items = array();

    /**
     * GuestBook _constructor
     *
     * GuestBook init függvény
     *
     * @param string "dbfile": Alapértelmezett adatbázisfájl módosítása
     * @return none
     */
    public function GuestBook($dbfile = "") {
      if (file_exists($this->dbfile)) {
        $this->items = file($this->dbfile);
        if (count($this->items) > 0) {
          array_walk($this->items, create_function('&$val', '$val = json_decode($val, true);'));
        }
      }
    }

    /**
     * GuestBook->getItems
     *
     * Elemek tömbjének visszaadása
     *
     * @param none
     * @return array
     */
    public function getItems() {
      return $this->items;
    }

    /**
     * GuestBook->getLastId
     *
     * Utolsó elem azonosítójának visszaadása
     *
     * @param none
     * @return integer
     */
    public function getLastId($plus = 0) {
      if (count($this->items) > 0) {
        $last_item = end($this->items);
        return ($last_item["id"] + $plus);
      } else {
        return (0 + $plus);
      }
    }

    /**
     * GuestBook->addItem
     *
     * Elem hozzáadása
     *
     * @param string "name": Név
     * @param string "mail": e-Mail cím
     * @param string "msg": Üzenet szövege
     * @return none
     */
    public function addItem($name, $mail, $msg) {
      $this->items[] = array("id"=>$this->getLastId(1), "ts"=>time(), "name"=>htmlspecialchars($name), "mail"=>htmlspecialchars($mail), "msg"=>htmlspecialchars($msg));
      $this->saveItems();
    }

    /**
     * GuestBook->editItem
     *
     * Elem szerkesztése
     *
     * @param string "id": Elemazonosító
     * @param string "name": Új név
     * @param string "mail": Új e-Mail cím
     * @param string "msg": Üzenet új szövege
     * @return none
     */
    public function editItem($id, $name = "", $mail = "", $msg = "") {
      if (!empty($name) && !is_null($name)) {
        $this->items[$id]["name"] = htmlspecialchars($name);
      }
      if (!empty($mail) && !is_null($mail)) {
        $this->items[$id]["mail"] = htmlspecialchars($mail);
      }
      if (!empty($msg) && !is_null($msg)) {
        $this->items[$id]["msg"] = htmlspecialchars($msg);
      }
      $this->saveItems();
    }

    /**
     * GuestBook->removeItem
     *
     * Elem törlése
     *
     * @param string "id": Elemazonosító
     * @return none
     */
    public function removeItem($id) {
      $item_i=0;
      foreach ($this->items as $item) {
        if ($item["id"] == $id) {
          unset($this->items[$item_i]);
        }
        $item_i++;
      }
      $this->saveItems();
    }

    /**
     * GuestBook->clearItems
     *
     * Összes elem törlése
     *
     * @param none
     * @return none
     */
    public function clearItems() {
      file_put_contents($this->dbfile, "");
    }

    /**
     * GuestBook->saveItems
     *
     * Elemek mentése
     *
     * @param none
     * @return none
     */
    private function saveItems() {
      $temp_items = $this->items;
      array_walk($temp_items, create_function('&$val', '$val = json_encode($val);'));
      file_put_contents($this->dbfile, implode("\n", $temp_items));
    }
  }
?>